@@ -40,6 +40,7 @@
 #'   # NOTE: You normally want to use ALL cores for this, not just 2.
 #' cv_hbam_mini <- hbam_cv(self, stimuli, model = "HBAM_MINI",
 #'                         cores = 2, warmup = 500, iter = 1000)
+#' cv_hbam_mini
 #' }
 
 hbam_cv <- function(self = NULL, stimuli = NULL, model = "HBAM",
@@ -83,7 +84,7 @@ hbam_cv <- function(self = NULL, stimuli = NULL, model = "HBAM",
                             set.seed(seed + i)
                             init_l <- list(inits[[model]](chain_id = i, dat = dat_l[[k]]))
                             # Obtain chain:
-                            s <- rstan::sampling(stanmodels[[model]], data = dat_l[[k]], init = init_l,
+                            s <- rstan::sampling(stanmodels[[model]], data = dat_l[[k]], init = init_l, pars = "log_lik",
                                                  chains = 1, cores = 1, warmup = warmup, iter = iter, thin = thin, chain_id = i, seed = seed + i, ...)
                             # Calculate expected value of log-likelihood for each held-out observation:
                             log_lik <- loo::extract_log_lik(s)
