@@ -12,7 +12,7 @@ inits_HBAM <- function(chain_id = 1, dat) {
     nu = 3 + rinvchisq(1, 100, 7),
     tau = rinvchisq(1, 500, (dat$B / 3)),
     eta = rinvchisq(dat$N, 100, dat$J^2 * (dat$B / 3)^2),
-    rho = c(rdirichlet(1, rep(50, dat$J))),
+    rho = rdirichlet(1, rep(50, dat$J)),
     logit_lambda = rnorm(dat$N, 0, .2),
     psi = exp(rnorm(1, 1.4, .1)),
     # For HBAM_ORIG:
@@ -42,7 +42,7 @@ inits_HBAM_NF <- function(chain_id = 1, dat) {
     nu = 3 + rinvchisq(1, 100, 7),
     tau = rinvchisq(1, 500, (dat$B / 3)),
     eta = rinvchisq(dat$N, 100, dat$J^2 * (dat$B / 3)^2),
-    rho = c(rdirichlet(1, rep(50, dat$J))),
+    rho = rdirichlet(1, rep(50, dat$J)),
     # For HBAM_MULTI:
     mu_alpha_raw = rdirichlet(1, rep(500, dat$G)),
     mu_beta_raw = rdirichlet(1, rep(500, dat$G))
@@ -57,7 +57,7 @@ inits_BAM <- function(chain_id = 1, dat) {
     nu = 3 + rinvchisq(1, 100, 7),
     tau = rinvchisq(1, 500, (dat$B / 3)),
     eta = rinvchisq(dat$N, 100, dat$J^2 * (dat$B / 3)^2),
-    rho = c(rdirichlet(1, rep(50, dat$J)))
+    rho = rdirichlet(1, rep(50, dat$J))
   )
 }
 
@@ -65,7 +65,7 @@ inits_BAM <- function(chain_id = 1, dat) {
 inits <- list(
   HBAM = inits_HBAM,
   #HBAM_ORIG = inits_HBAM,
-  HBAM_MAX = inits_HBAM,
+  #HBAM_MAX = inits_HBAM,
   # HBAM_2 = inits_HBAM,
   # HBAM_HM = inits_HBAM,
   HBAM_MINI = inits_HBAM,
@@ -87,5 +87,7 @@ rdirichlet <- function (n, alpha) {
   l <- length(alpha)
   x <- matrix(rgamma(l * n, alpha), ncol = l, byrow = TRUE)
   sm <- x %*% rep(1, l)
-  return(x / as.vector(sm))
+  out <- x / as.vector(sm)
+  if (n == 1) { out <- c(out) }
+  return(out)
 }
